@@ -16,7 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """
-AWS Batch service waiters
+AWS Batch service waiters.
 
 .. seealso::
 
@@ -29,6 +29,7 @@ import json
 import sys
 from copy import deepcopy
 from pathlib import Path
+from typing import Callable
 
 import botocore.client
 import botocore.exceptions
@@ -36,6 +37,7 @@ import botocore.waiter
 
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.batch_client import BatchClientHook
+from airflow.providers.amazon.aws.utils.task_log_fetcher import AwsTaskLogFetcher
 
 
 class BatchWaitersHook(BatchClientHook):
@@ -107,7 +109,7 @@ class BatchWaitersHook(BatchClientHook):
     @property
     def default_config(self) -> dict:
         """
-        An immutable default waiter configuration
+        An immutable default waiter configuration.
 
         :return: a waiter configuration for AWS Batch services
         """
@@ -184,7 +186,12 @@ class BatchWaitersHook(BatchClientHook):
         """
         return self.waiter_model.waiter_names
 
-    def wait_for_job(self, job_id: str, delay: int | float | None = None) -> None:
+    def wait_for_job(
+        self,
+        job_id: str,
+        delay: int | float | None = None,
+        get_batch_log_fetcher: Callable[[str], AwsTaskLogFetcher | None] | None = None,
+    ) -> None:
         """
         Wait for Batch job to complete.  This assumes that the ``.waiter_model`` is configured
         using some variation of the ``.default_config`` so that it can generate waiters with the
@@ -194,6 +201,9 @@ class BatchWaitersHook(BatchClientHook):
 
         :param delay:  A delay before polling for job status
 
+        :param get_batch_log_fetcher: A method that returns batch_log_fetcher of
+            type AwsTaskLogFetcher or None when the CloudWatch log stream hasn't been created yet.
+
         :raises: AirflowException
 
         .. note::
@@ -216,10 +226,20 @@ class BatchWaitersHook(BatchClientHook):
             waiter.config.max_attempts = sys.maxsize  # timeout is managed by Airflow
             waiter.wait(jobs=[job_id])
 
-            waiter = self.get_waiter("JobComplete")
-            waiter.config.delay = self.add_jitter(waiter.config.delay, width=2, minima=1)
-            waiter.config.max_attempts = sys.maxsize  # timeout is managed by Airflow
-            waiter.wait(jobs=[job_id])
+            batch_log_fetcher = None
+            try:
+                if get_batch_log_fetcher:
+                    batch_log_fetcher = get_batch_log_fetcher(job_id)
+                    if batch_log_fetcher:
+                        batch_log_fetcher.start()
+                waiter = self.get_waiter("JobComplete")
+                waiter.config.delay = self.add_jitter(waiter.config.delay, width=2, minima=1)
+                waiter.config.max_attempts = sys.maxsize  # timeout is managed by Airflow
+                waiter.wait(jobs=[job_id])
+            finally:
+                if batch_log_fetcher:
+                    batch_log_fetcher.stop()
+                    batch_log_fetcher.join()
 
         except (botocore.exceptions.ClientError, botocore.exceptions.WaiterError) as err:
             raise AirflowException(err)
