@@ -19,23 +19,23 @@ from __future__ import annotations
 
 import re
 import sys
+import warnings
 from datetime import timedelta
+from functools import cached_property
 from typing import TYPE_CHECKING, Sequence
 
 import boto3
 
-from airflow.compat.functools import cached_property
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator, XCom
 from airflow.providers.amazon.aws.exceptions import EcsOperatorError, EcsTaskFailToStart
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.providers.amazon.aws.hooks.ecs import (
     EcsClusterStates,
     EcsHook,
-    EcsTaskDefinitionStates,
-    EcsTaskLogFetcher,
     should_retry_eni,
 )
+from airflow.providers.amazon.aws.utils.task_log_fetcher import AwsTaskLogFetcher
 from airflow.utils.helpers import prune_dict
 from airflow.utils.session import provide_session
 
@@ -202,53 +202,39 @@ class EcsDeregisterTaskDefinitionOperator(EcsBaseOperator):
 
     :param task_definition: The family and revision (family:revision) or full Amazon Resource Name (ARN)
         of the task definition to deregister. If you use a family name, you must specify a revision.
-    :param wait_for_completion: If True, waits for creation of the cluster to complete. (default: True)
-    :param waiter_delay: The amount of time in seconds to wait between attempts,
-        if not set then the default waiter value will be used.
-    :param waiter_max_attempts: The maximum number of attempts to be made,
-        if not set then the default waiter value will be used.
     """
 
-    template_fields: Sequence[str] = ("task_definition", "wait_for_completion")
+    template_fields: Sequence[str] = "task_definition"
 
     def __init__(
         self,
         *,
         task_definition: str,
-        wait_for_completion: bool = True,
-        waiter_delay: int | None = None,
-        waiter_max_attempts: int | None = None,
         **kwargs,
     ):
+        if "wait_for_completion" in kwargs or "waiter_delay" in kwargs or "waiter_max_attempts" in kwargs:
+            warnings.warn(
+                "'wait_for_completion' and waiter related params have no effect and are deprecated, "
+                "please remove them.",
+                AirflowProviderDeprecationWarning,
+                stacklevel=2,
+            )
+            # remove args to not trigger Invalid arguments exception
+            kwargs.pop("wait_for_completion", None)
+            kwargs.pop("waiter_delay", None)
+            kwargs.pop("waiter_max_attempts", None)
+
         super().__init__(**kwargs)
         self.task_definition = task_definition
-        self.wait_for_completion = wait_for_completion
-        self.waiter_delay = waiter_delay
-        self.waiter_max_attempts = waiter_max_attempts
 
     def execute(self, context: Context):
         self.log.info("Deregistering task definition %s.", self.task_definition)
         result = self.client.deregister_task_definition(taskDefinition=self.task_definition)
         task_definition_details = result["taskDefinition"]
         task_definition_arn = task_definition_details["taskDefinitionArn"]
-        task_definition_state = task_definition_details.get("status")
-
-        if task_definition_state == EcsTaskDefinitionStates.INACTIVE:
-            # In some circumstances the ECS Task Definition is deleted immediately,
-            # so there is no reason to wait for completion.
-            self.log.info("Task Definition %r in state: %r.", task_definition_arn, task_definition_state)
-        elif self.wait_for_completion:
-            waiter = self.hook.get_waiter("task_definition_inactive")
-            waiter.wait(
-                taskDefinition=task_definition_arn,
-                WaiterConfig=prune_dict(
-                    {
-                        "Delay": self.waiter_delay,
-                        "MaxAttempts": self.waiter_max_attempts,
-                    }
-                ),
-            )
-
+        self.log.info(
+            "Task Definition %r in state: %r.", task_definition_arn, task_definition_details.get("status")
+        )
         return task_definition_arn
 
 
@@ -264,18 +250,12 @@ class EcsRegisterTaskDefinitionOperator(EcsBaseOperator):
     :param container_definitions: A list of container definitions in JSON format that describe
         the different containers that make up your task.
     :param register_task_kwargs: Extra arguments for Register Task Definition.
-    :param wait_for_completion: If True, waits for creation of the cluster to complete. (default: True)
-    :param waiter_delay: The amount of time in seconds to wait between attempts,
-        if not set then the default waiter value will be used.
-    :param waiter_max_attempts: The maximum number of attempts to be made,
-        if not set then the default waiter value will be used.
     """
 
     template_fields: Sequence[str] = (
         "family",
         "container_definitions",
         "register_task_kwargs",
-        "wait_for_completion",
     )
 
     def __init__(
@@ -284,18 +264,24 @@ class EcsRegisterTaskDefinitionOperator(EcsBaseOperator):
         family: str,
         container_definitions: list[dict],
         register_task_kwargs: dict | None = None,
-        wait_for_completion: bool = True,
-        waiter_delay: int | None = None,
-        waiter_max_attempts: int | None = None,
         **kwargs,
     ):
+        if "wait_for_completion" in kwargs or "waiter_delay" in kwargs or "waiter_max_attempts" in kwargs:
+            warnings.warn(
+                "'wait_for_completion' and waiter related params have no effect and are deprecated, "
+                "please remove them.",
+                AirflowProviderDeprecationWarning,
+                stacklevel=2,
+            )
+            # remove args to not trigger Invalid arguments exception
+            kwargs.pop("wait_for_completion", None)
+            kwargs.pop("waiter_delay", None)
+            kwargs.pop("waiter_max_attempts", None)
+
         super().__init__(**kwargs)
         self.family = family
         self.container_definitions = container_definitions
         self.register_task_kwargs = register_task_kwargs or {}
-        self.wait_for_completion = wait_for_completion
-        self.waiter_delay = waiter_delay
-        self.waiter_max_attempts = waiter_max_attempts
 
     def execute(self, context: Context):
         self.log.info(
@@ -311,31 +297,17 @@ class EcsRegisterTaskDefinitionOperator(EcsBaseOperator):
         )
         task_definition_details = response["taskDefinition"]
         task_definition_arn = task_definition_details["taskDefinitionArn"]
-        task_definition_state = task_definition_details.get("status")
-
-        if task_definition_state == EcsTaskDefinitionStates.ACTIVE:
-            # In some circumstances the ECS Task Definition is created immediately,
-            # so there is no reason to wait for completion.
-            self.log.info("Task Definition %r in state: %r.", task_definition_arn, task_definition_state)
-        elif self.wait_for_completion:
-            waiter = self.hook.get_waiter("task_definition_active")
-            waiter.wait(
-                taskDefinition=task_definition_arn,
-                WaiterConfig=prune_dict(
-                    {
-                        "Delay": self.waiter_delay,
-                        "MaxAttempts": self.waiter_max_attempts,
-                    }
-                ),
-            )
 
+        self.log.info(
+            "Task Definition %r in state: %r.", task_definition_arn, task_definition_details.get("status")
+        )
         context["ti"].xcom_push(key="task_definition_arn", value=task_definition_arn)
         return task_definition_arn
 
 
 class EcsRunTaskOperator(EcsBaseOperator):
     """
-    Execute a task on AWS ECS (Elastic Container Service)
+    Execute a task on AWS ECS (Elastic Container Service).
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -475,11 +447,22 @@ class EcsRunTaskOperator(EcsBaseOperator):
 
         self.arn: str | None = None
         self.retry_args = quota_retry
-        self.task_log_fetcher: EcsTaskLogFetcher | None = None
+        self.task_log_fetcher: AwsTaskLogFetcher | None = None
         self.wait_for_completion = wait_for_completion
         self.waiter_delay = waiter_delay
         self.waiter_max_attempts = waiter_max_attempts
 
+        if self._aws_logs_enabled() and not self.wait_for_completion:
+            self.log.warning(
+                "Trying to get logs without waiting for the task to complete is undefined behavior."
+            )
+
+    @staticmethod
+    def _get_ecs_task_id(task_arn: str | None) -> str | None:
+        if task_arn is None:
+            return None
+        return task_arn.split("/")[-1]
+
     @provide_session
     def execute(self, context, session=None):
         self.log.info(
@@ -506,25 +489,24 @@ class EcsRunTaskOperator(EcsBaseOperator):
 
     @AwsBaseHook.retry(should_retry_eni)
     def _start_wait_check_task(self, context):
-
         if not self.arn:
             self._start_task(context)
 
+        if not self.wait_for_completion:
+            return
+
         if self._aws_logs_enabled():
             self.log.info("Starting ECS Task Log Fetcher")
             self.task_log_fetcher = self._get_task_log_fetcher()
             self.task_log_fetcher.start()
 
             try:
-                if self.wait_for_completion:
-                    self._wait_for_task_ended()
+                self._wait_for_task_ended()
             finally:
                 self.task_log_fetcher.stop()
-
             self.task_log_fetcher.join()
         else:
-            if self.wait_for_completion:
-                self._wait_for_task_ended()
+            self._wait_for_task_ended()
 
         self._check_success_task()
 
@@ -566,8 +548,7 @@ class EcsRunTaskOperator(EcsBaseOperator):
         self.log.info("ECS Task started: %s", response)
 
         self.arn = response["tasks"][0]["taskArn"]
-        self.ecs_task_id = self.arn.split("/")[-1]
-        self.log.info("ECS task ID is: %s", self.ecs_task_id)
+        self.log.info("ECS task ID is: %s", self._get_ecs_task_id(self.arn))
 
         if self.reattach:
             # Save the task ARN in XCom to be able to reattach it if needed
@@ -590,7 +571,6 @@ class EcsRunTaskOperator(EcsBaseOperator):
         )
         if previous_task_arn in running_tasks:
             self.arn = previous_task_arn
-            self.ecs_task_id = self.arn.split("/")[-1]
             self.log.info("Reattaching previously launched task: %s", self.arn)
         else:
             self.log.info("No active previously launched task found to reattach")
@@ -617,12 +597,12 @@ class EcsRunTaskOperator(EcsBaseOperator):
     def _aws_logs_enabled(self):
         return self.awslogs_group and self.awslogs_stream_prefix
 
-    def _get_task_log_fetcher(self) -> EcsTaskLogFetcher:
+    def _get_task_log_fetcher(self) -> AwsTaskLogFetcher:
         if not self.awslogs_group:
             raise ValueError("must specify awslogs_group to fetch task logs")
-        log_stream_name = f"{self.awslogs_stream_prefix}/{self.ecs_task_id}"
+        log_stream_name = f"{self.awslogs_stream_prefix}/{self._get_ecs_task_id(self.arn)}"
 
-        return EcsTaskLogFetcher(
+        return AwsTaskLogFetcher(
             aws_conn_id=self.aws_conn_id,
             region_name=self.awslogs_region,
             log_group=self.awslogs_group,
