@@ -17,12 +17,15 @@
 # under the License.
 from __future__ import annotations
 
+from functools import cached_property
 from typing import TYPE_CHECKING, Sequence
 
+from airflow import AirflowException
+from airflow.providers.amazon.aws.triggers.glue_crawler import GlueCrawlerCompleteTrigger
+
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
-from airflow.compat.functools import cached_property
 from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.glue_crawler import GlueCrawlerHook
 
@@ -40,7 +43,10 @@ class GlueCrawlerOperator(BaseOperator):
     :param config: Configurations for the AWS Glue crawler
     :param aws_conn_id: aws connection to use
     :param poll_interval: Time (in seconds) to wait between two consecutive calls to check crawler status
-    :param wait_for_completion: Whether or not wait for crawl execution completion. (default: True)
+    :param wait_for_completion: Whether to wait for crawl execution completion. (default: True)
+    :param deferrable: If True, the operator will wait asynchronously for the crawl to complete.
+        This implies waiting for completion. This mode requires aiobotocore module to be installed.
+        (default: False)
     """
 
     template_fields: Sequence[str] = ("config",)
@@ -50,24 +56,28 @@ class GlueCrawlerOperator(BaseOperator):
         self,
         config,
         aws_conn_id="aws_default",
+        region_name: str | None = None,
         poll_interval: int = 5,
         wait_for_completion: bool = True,
+        deferrable: bool = False,
         **kwargs,
     ):
         super().__init__(**kwargs)
         self.aws_conn_id = aws_conn_id
         self.poll_interval = poll_interval
         self.wait_for_completion = wait_for_completion
+        self.deferrable = deferrable
+        self.region_name = region_name
         self.config = config
 
     @cached_property
     def hook(self) -> GlueCrawlerHook:
-        """Create and return an GlueCrawlerHook."""
-        return GlueCrawlerHook(self.aws_conn_id)
+        """Create and return a GlueCrawlerHook."""
+        return GlueCrawlerHook(self.aws_conn_id, region_name=self.region_name)
 
     def execute(self, context: Context):
         """
-        Executes AWS Glue Crawler from Airflow
+        Executes AWS Glue Crawler from Airflow.
 
         :return: the name of the current glue crawler.
         """
@@ -79,8 +89,22 @@ class GlueCrawlerOperator(BaseOperator):
 
         self.log.info("Triggering AWS Glue Crawler")
         self.hook.start_crawler(crawler_name)
-        if self.wait_for_completion:
+        if self.deferrable:
+            self.defer(
+                trigger=GlueCrawlerCompleteTrigger(
+                    crawler_name=crawler_name,
+                    poll_interval=self.poll_interval,
+                    aws_conn_id=self.aws_conn_id,
+                ),
+                method_name="execute_complete",
+            )
+        elif self.wait_for_completion:
             self.log.info("Waiting for AWS Glue Crawler")
             self.hook.wait_for_crawler_completion(crawler_name=crawler_name, poll_interval=self.poll_interval)
 
         return crawler_name
+
+    def execute_complete(self, context, event=None):
+        if event["status"] != "success":
+            raise AirflowException(f"Error in glue crawl: {event}")
+        return self.config["Name"]
