@@ -17,8 +17,11 @@
 from __future__ import annotations
 
 import json
+from functools import cached_property
 from typing import TYPE_CHECKING, Sequence
 
+from deprecated import deprecated
+
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.step_function import StepFunctionHook
 from airflow.sensors.base import BaseSensorOperator
@@ -68,10 +71,9 @@ class StepFunctionExecutionSensor(BaseSensorOperator):
         self.execution_arn = execution_arn
         self.aws_conn_id = aws_conn_id
         self.region_name = region_name
-        self.hook: StepFunctionHook | None = None
 
     def poke(self, context: Context):
-        execution_status = self.get_hook().describe_execution(self.execution_arn)
+        execution_status = self.hook.describe_execution(self.execution_arn)
         state = execution_status["status"]
         output = json.loads(execution_status["output"]) if "output" in execution_status else None
 
@@ -85,10 +87,11 @@ class StepFunctionExecutionSensor(BaseSensorOperator):
         self.xcom_push(context, "output", output)
         return True
 
+    @deprecated(reason="use `hook` property instead.")
     def get_hook(self) -> StepFunctionHook:
-        """Create and return a StepFunctionHook"""
-        if self.hook:
-            return self.hook
-
-        self.hook = StepFunctionHook(aws_conn_id=self.aws_conn_id, region_name=self.region_name)
+        """Create and return a StepFunctionHook."""
         return self.hook
+
+    @cached_property
+    def hook(self) -> StepFunctionHook:
+        return StepFunctionHook(aws_conn_id=self.aws_conn_id, region_name=self.region_name)
