@@ -25,12 +25,12 @@ import json
 from copy import copy
 from datetime import datetime
 from decimal import Decimal
+from functools import cached_property
 from os.path import getsize
 from tempfile import NamedTemporaryFile
 from typing import IO, TYPE_CHECKING, Any, Callable, Sequence
 from uuid import uuid4
 
-from airflow.compat.functools import cached_property
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
 from airflow.providers.amazon.aws.hooks.dynamodb import DynamoDBHook
 from airflow.providers.amazon.aws.hooks.s3 import S3Hook
@@ -41,7 +41,7 @@ if TYPE_CHECKING:
 
 
 class JSONEncoder(json.JSONEncoder):
-    """Custom json encoder implementation"""
+    """Custom json encoder implementation."""
 
     def default(self, obj):
         """Convert decimal objects in a json serializable format."""
@@ -136,7 +136,7 @@ class DynamoDBToS3Operator(AwsToAwsBaseOperator):
 
     @cached_property
     def hook(self):
-        """Create DynamoDBHook"""
+        """Create DynamoDBHook."""
         return DynamoDBHook(aws_conn_id=self.source_aws_conn_id)
 
     def execute(self, context: Context) -> None:
