@@ -16,12 +16,15 @@
 # under the License.
 from __future__ import annotations
 
+import logging
 import re
 from datetime import datetime
 from enum import Enum
 
 from airflow.version import version
 
+log = logging.getLogger(__name__)
+
 
 def trim_none_values(obj: dict):
     return {key: val for key, val in obj.items() if val is not None}
